package WSM101 "The package for the Wolfram System Modeler 101 Course"
  extends Modelica.Icons.Package;

  model ElectricKettle "model for an electric Kettle, where you can plug in your brand new ElectricCircuit Class"
    extends Modelica.Icons.Example;
    Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor1(C = 4180) annotation(Placement(visible = true, transformation(origin = {-4.181, 31.793}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Thermal.HeatTransfer.Components.BodyRadiation bodyRadiation1(Gr = 0.15) annotation(Placement(visible = true, transformation(origin = {-3.941, -36.573}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Thermal.HeatTransfer.Celsius.TemperatureSensor temperatureSensor1 annotation(Placement(visible = true, transformation(origin = {28.806, -7.171}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const(k = 99) annotation(Placement(visible = true, transformation(origin = {26.059, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Logical.OnOffController onOffController1 annotation(Placement(visible = true, transformation(origin = {60, 12.908}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature fixedTemperature1(T = 20) annotation(Placement(visible = true, transformation(origin = {13.625, -76.372}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(heatCapacitor1.port, bodyRadiation1.port_a) annotation(Line(visible = true, origin = {-4.061, 7.201}, points = {{-0.12, 14.591}, {-0.12, 9.591}, {0.12, 9.591}, {0.12, -33.774}}, color = {191, 0, 0}));
    connect(temperatureSensor1.port, heatCapacitor1.port) annotation(Line(visible = true, origin = {3.481, 2.484}, points = {{15.325, -9.655}, {-7.662, -9.655}, {-7.662, 19.309}}, color = {191, 0, 0}));
    connect(temperatureSensor1.T, onOffController1.u) annotation(Line(visible = true, origin = {44.935, -2.478}, points = {{-6.129, -4.693}, {3.065, -4.693}, {3.065, 9.386}}, color = {1, 37, 163}));
    connect(const.y, onOffController1.reference) annotation(Line(visible = true, origin = {44.353, 26.303}, points = {{-7.294, 3.697}, {3.647, 3.697}, {3.647, -7.395}}, color = {1, 37, 163}));
    connect(fixedTemperature1.port, bodyRadiation1.port_b) annotation(Line(visible = true, origin = {14.599, -64.412}, points = {{9.027, -11.96}, {14.027, -11.96}, {14.027, 3.04}, {-18.54, 3.04}, {-18.54, 17.84}}, color = {191, 0, 0}));
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, textColor = {64, 64, 64}, extent = {{-150, 110}, {150, 150}}, textString = "%name")}));
  end ElectricKettle;

  model theOutsideWorldfortheKettle "Testing the electric Kettle"
    Modelica.Electrical.Analog.Basic.Ground ground1 annotation(Placement(visible = true, transformation(origin = {-8.247, -56.293}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Electrical.Analog.Sources.SineVoltage sineVoltage1(V = 230, freqHz = 50) annotation(Placement(visible = true, transformation(origin = {-77.089, -24.382}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
    Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature ambientTemperature(T(displayUnit = "degC") = 20) annotation(Placement(visible = true, transformation(origin = {-46.254, -16.494}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(sineVoltage1.n, ground1.p) annotation(Line(visible = true, origin = {-42.668, -39.86}, points = {{-34.421, 5.478}, {-34.421, 0.478}, {34.421, 0.478}, {34.421, -6.434}}, color = {10, 90, 224}));
    annotation(experiment(StopTime = 300.0), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {0, 114, 195}, fillColor = {255, 255, 255}, extent = {{-100, -100}, {100, 100}}, radius = 25), Text(visible = true, textColor = {64, 64, 64}, extent = {{-150, 110}, {150, 150}}, textString = "%name")}));
  end theOutsideWorldfortheKettle;

  package Ex5
    extends Modelica.Icons.Package;

    model MotorForInvertedPendulum
      extends Modelica.Icons.Example;
      Modelica.Electrical.Analog.Basic.Inductor inductor1 annotation(Placement(visible = true, transformation(origin = {20.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -1440)));
      Modelica.Electrical.Analog.Basic.EMF EMF1 annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.Ground ground1 annotation(Placement(visible = true, transformation(origin = {0.0, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Sources.SignalVoltage signalVoltage1 annotation(Placement(visible = true, transformation(origin = {-40.0, 0.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 1350)));
      Modelica.Mechanics.Rotational.Components.Inertia inertia1(J = 0.1) annotation(Placement(visible = true, transformation(origin = {80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(EMF1.flange, inertia1.flange_a) annotation(Line(visible = true, origin = {60, 0}, points = {{-10, 0}, {10, 0}}));
      connect(inductor1.n, EMF1.p) annotation(Line(visible = true, origin = {36.6667, 16.6667}, points = {{-6.6667, 3.3333}, {3.3333, 3.3333}, {3.3333, -6.6667}}, color = {0, 0, 255}));
      connect(EMF1.n, signalVoltage1.n) annotation(Line(visible = true, origin = {0.0, -18.5}, points = {{40.0, 8.5}, {40.0, -1.5}, {-40.0, -1.5}, {-40.0, 8.5}}, color = {0, 0, 255}));
      connect(ground1.p, signalVoltage1.n) annotation(Line(visible = true, origin = {-30.0, -19.375}, points = {{30.0, -10.625}, {30.0, -0.625}, {-10.0, -0.625}, {-10.0, 9.375}}, color = {0, 0, 255}));
      annotation(experiment(StartTime = 0.0, StopTime = 25), Documentation(info = "<p>A simple dynamic model of a controlled DC motor consisting of a variable voltage source, a resistor, an inductor, and an electro-motoric force element representing the coupling between electric energy and mechanical energy provided by the magnetic field in the DC motor.</p>
   <ul>
   <li>Add a resistor from Modelica.Electrical.Basic.Resitor</li>
   <li>Connect it to the inductor and the signal voltage</li>
   <li>Search for Ramp in the Class Browser. Add it to the diagram view and connect it to the <em>signalVoltage</em>. Set the parameter <em>duration</em>&nbsp;to 5. Set the parameter height to 10.</li>
   <li>Simulate the system and plot inertia1.w</li>
   </ul>", revisions = ""), Diagram(coordinateSystem(extent = {{-100.0, -60.0}, {100.0, 60.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, fillPattern = FillPattern.Solid, extent = {{-100.0, -150.0}, {100.0, -110.0}}, textString = "%name", fontName = "Arial")}));
    end MotorForInvertedPendulum;

    model InvertedPendulum "A Multibody Pendulum"
      extends Modelica.Icons.Example;
      inner Modelica.Mechanics.MultiBody.World world annotation(Placement(visible = true, transformation(origin = {-80.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.MultiBody.Joints.Revolute revolute1 annotation(Placement(visible = true, transformation(origin = {-40.0, -0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    equation
      connect(world.frame_b, revolute1.frame_a) annotation(Line(visible = true, origin = {-60.0, 0.0}, points = {{-10.0, 0.0}, {10.0, -0.0}}));
      annotation(experiment(StopTime = 10), Documentation(info = "<ul>
   <li><span style=\"font-family: arial, helvetica, sans-serif; font-size: medium;\">Add a cylinder from Modelica.Mechanics.MultiBody.Parts.Cylinder</span></li>
   <li><span style=\"font-family: arial, helvetica, sans-serif; font-size: medium;\">Set the parameter r[3] to {1,0,0}</span></li>
   <li><span style=\"font-family: arial, helvetica, sans-serif; font-size: medium;\">Simulate the model</span></li>
   </ul>", revisions = ""), Diagram(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end InvertedPendulum;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
  end Ex5;

  package Ex6 "Models accompanying Exercise 6 of the WSM101 Course"
    extends Modelica.Icons.Package;

    model BatteryPowertrain
      extends Modelica.Icons.Example;
      Modelica.Electrical.Analog.Basic.EMF emf(k = 0.1) annotation(Placement(visible = true, transformation(origin = {-40.0, 20.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.Ground ground annotation(Placement(visible = true, transformation(origin = {60.0, -30.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.Inertia inertia(J = 1) annotation(Placement(visible = true, transformation(origin = {-20.0, 60.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature fixedTemperature(T = 22) annotation(Placement(visible = true, transformation(origin = {-40.0, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -720)));
      Modelica.Mechanics.Rotational.Components.Inertia inertia1(J = 1) annotation(Placement(visible = true, transformation(origin = {60.0, 60.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.Spring spring1(c = 10) annotation(Placement(visible = true, transformation(origin = {20.0, 60.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.Spring spring(c = 10) annotation(Placement(visible = true, transformation(origin = {-60.0, 60.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
      Modelica.Mechanics.Rotational.Sources.TorqueStep torqueStep(stepTorque = -1, startTime = 150) annotation(Placement(visible = true, transformation(origin = {100.0, 60.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
      BatteryCell batteryCell1 annotation(Placement(visible = true, transformation(origin = {16.628, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      annotation(Documentation(info = "<ol>
   <li>Connect the components together</li>
   <li>Simulate and plot inertia1.w and batteryCell.SoCOutput</li>
   </ol><ol> </ol>", revisions = ""), experiment(StopTime = 1000), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end BatteryPowertrain;

    model BatteryWind
      extends Modelica.Icons.Example;
      Modelica.Thermal.HeatTransfer.Celsius.FixedTemperature fixedTemperature(T = 25) annotation(Placement(visible = true, transformation(origin = {-40.0, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Sources.Sine sine(freqHz = 1 / 86400, amplitude = 0.02, offset = 0.02) annotation(Placement(visible = true, transformation(origin = {-80.0, 80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Sources.Torque torque annotation(Placement(visible = true, transformation(origin = {-40.0, 80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.EMF emf(k = 1) annotation(Placement(visible = true, transformation(origin = {-0.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
      Modelica.Electrical.Analog.Basic.Ground ground annotation(Placement(visible = true, transformation(origin = {40.0, -20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      BatteryCell batteryCell1(initialStateOfCharge = 0.12) annotation(Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      annotation(experiment(StartTime = 0.0, StopTime = 130000, NumberOfIntervals = -1, __Wolfram_Algorithm = "dassl"), Documentation(info = "<p>Connect the components together.Simulate and plot batteryCell.SoCOutput and sine.y.</p>", revisions = ""), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end BatteryWind;

    model BatteryCell "The main battery cell model"
      Modelica.Electrical.Analog.Basic.Ground ground annotation(Placement(visible = true, transformation(origin = {-90.0, -90.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      IndustryExamples.Energy.Battery.Components.CircuitElements.StateOfHealthCapacitor capacity(initialStateOfCharge = initialStateOfCharge) annotation(Placement(visible = true, transformation(origin = {-130.0, -60.0}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 90)));
      IndustryExamples.Energy.Battery.Components.CircuitElements.OpenCircuitVoltage openCircuitVoltage annotation(Placement(visible = true, transformation(origin = {-30.0, -60.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -90)));
      Modelica.Electrical.Analog.Sensors.CurrentSensor drawnCurrent annotation(Placement(visible = true, transformation(origin = {-30.0, -20.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 90)));
      Modelica.Electrical.Analog.Interfaces.NegativePin n annotation(Placement(visible = true, transformation(origin = {150.0, -80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {100.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Interfaces.PositivePin p annotation(Placement(visible = true, transformation(origin = {150.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {-100.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Sensors.TemperatureSensor temperature annotation(Placement(visible = true, transformation(origin = {-30.0, 90.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 180)));
      Modelica.Electrical.Analog.Sensors.PotentialSensor stateOfCharge annotation(Placement(visible = true, transformation(origin = {-110.0, 90.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 720)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heat annotation(Placement(visible = true, transformation(origin = {0.0, 105.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360), iconTransformation(origin = {-0.0, -100.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Routing.Multiplex3 batteryState annotation(Placement(visible = true, transformation(origin = {-70.0, 60.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = -90)));
      IndustryExamples.Energy.Battery.Components.CircuitElements.ProtectedSignalCurrent drainCurrent annotation(Placement(visible = true, transformation(origin = {-90.0, -20.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = -270)));
      parameter Real initialStateOfCharge = 0.9;
      IndustryExamples.Energy.Battery.Components.CircuitElements.SeriesResistance seriesResistance annotation(Placement(visible = true, transformation(origin = {-0.0, 0.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 0)));
      IndustryExamples.Energy.Battery.Components.CircuitElements.ShortTransientCapacitance shortTransientC annotation(Placement(visible = true, transformation(origin = {40.0, 20.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 0)));
      IndustryExamples.Energy.Battery.Components.CircuitElements.ShortTransientResistance shortTransientR annotation(Placement(visible = true, transformation(origin = {40.0, -20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      IndustryExamples.Energy.Battery.Components.CircuitElements.LongTransientCapacitance longTransientC annotation(Placement(visible = true, transformation(origin = {100.0, 20.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 0)));
      IndustryExamples.Energy.Battery.Components.CircuitElements.LongTransientResistance longTransientR annotation(Placement(visible = true, transformation(origin = {100.0, -20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput SoCOutput annotation(Placement(visible = true, transformation(origin = {-90.0, 115.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270), iconTransformation(origin = {-100.0, 80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -180)));
      Modelica.Blocks.Interfaces.RealOutput CapacityOutput annotation(Placement(visible = true, transformation(origin = {-125.0, -110.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -90), iconTransformation(origin = {-100.0, -80.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -180)));
      Modelica.Blocks.Logical.LessThreshold LimitController(threshold = 0.102) annotation(Placement(visible = true, transformation(origin = {50, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Blocks.Logical.GreaterThreshold GreaterController(threshold = 0.92) annotation(Placement(visible = true, transformation(origin = {50, 90}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    algorithm
      when LimitController.y or GreaterController.y then
        terminate("Charge too low or too high");
      end when;
    equation
      connect(capacity.y, CapacityOutput) annotation(Line(visible = true, origin = {-125, -90}, points = {{0, 20}, {0, -20}}, color = {1, 37, 163}));
      connect(GreaterController.u, SoCOutput) annotation(Line(visible = true, origin = {55.5, 102.5}, points = {{-17.5, -12.5}, {-25.5, -12.5}, {-25.5, 12.5}, {-145.5, 12.5}}, color = {0, 36, 164}));
      connect(LimitController.u, SoCOutput) annotation(Line(visible = true, origin = {50.5, 92.5}, points = {{-12.5, -22.5}, {-25.5, -22.5}, {-25.5, 22.5}, {-140.5, 22.5}}, color = {0, 36, 164}));
      connect(stateOfCharge.phi, SoCOutput) annotation(Line(visible = true, origin = {-93, 98.333}, points = {{-6, -8.333}, {3, -8.333}, {3, 16.667}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5));
      connect(temperature.port, heat) annotation(Line(visible = true, origin = {-10.75, 93.75}, points = {{-9.25, -3.75}, {-2.25, -3.75}, {10.75, -3.75}, {10.75, 11.25}}, color = {191, 0, 0}));
      connect(stateOfCharge.phi, batteryState.u1[1]) annotation(Line(visible = true, origin = {-84.333, 84}, points = {{-14.667, 6}, {7.333, 6}, {7.333, -12}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5));
      connect(temperature.T, batteryState.u2[1]) annotation(Line(visible = true, origin = {-60, 84}, points = {{20, 6}, {-10, 6}, {-10, -12}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5));
      connect(batteryState.y[:], drainCurrent.batteryState[:]) annotation(Line(visible = true, origin = {-88.4, -0.2}, points = {{18.4, 49.2}, {18.4, 10.2}, {-21.6, 10.2}, {-21.6, -19.8}, {-13.6, -19.8}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5, smooth = Smooth.Bezier));
      connect(batteryState.y[:], capacity.batteryState[:]) annotation(Line(visible = true, origin = {-86, -30.333}, points = {{16, 79.333}, {16, -29.667}, {-32, -29.667}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5, smooth = Smooth.Bezier));
      connect(batteryState.y[:], openCircuitVoltage.batteryState[:]) annotation(Line(visible = true, origin = {-60.667, -23.667}, points = {{-9.333, 72.667}, {-9.333, -36.333}, {18.667, -36.333}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5, smooth = Smooth.Bezier));
      connect(drawnCurrent.i, drainCurrent.drawnCurrent) annotation(Line(visible = true, origin = {-61.5, -20}, points = {{21.5, 0}, {-21.5, 0}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5));
      connect(drawnCurrent.i, batteryState.u3[1]) annotation(Line(visible = true, origin = {-53.2, 38.4}, points = {{13.2, -58.4}, {3.2, -58.4}, {3.2, 41.6}, {-9.8, 41.6}, {-9.8, 33.6}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5));
      connect(batteryState.y[:], seriesResistance.batteryState[:]) annotation(Line(visible = true, origin = {-35, 20.25}, points = {{-35, 28.75}, {-35, -0.25}, {35, -0.25}, {35, -8.25}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5, smooth = Smooth.Bezier));
      connect(batteryState.y[:], shortTransientR.batteryState[:]) annotation(Line(visible = true, origin = {-15, -20.75}, points = {{-55, 69.75}, {-55, -19.25}, {55, -19.25}, {55, -11.25}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5, smooth = Smooth.Bezier));
      connect(batteryState.y[:], longTransientR.batteryState[:]) annotation(Line(visible = true, origin = {15, -20.75}, points = {{-85, 69.75}, {-85, -19.25}, {85, -19.25}, {85, -11.25}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5, smooth = Smooth.Bezier));
      connect(batteryState.y[:], longTransientC.batteryState[:]) annotation(Line(visible = true, origin = {15, 41.5}, points = {{-85, 7.5}, {-85, -4}, {85, 1}, {85, -9.5}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5, smooth = Smooth.Bezier));
      connect(batteryState.y[:], shortTransientC.batteryState[:]) annotation(Line(visible = true, origin = {-15, 39}, points = {{-55, 10}, {-55, -4}, {55, 1}, {55, -7}}, color = {1, 37, 163}, pattern = LinePattern.Dash, thickness = 0.5, smooth = Smooth.Bezier));
      connect(shortTransientR.n, longTransientC.p) annotation(Line(visible = true, origin = {70, 0}, points = {{-20, -20}, {-10, -20}, {-10, 0}, {10, 0}, {10, 20}, {20, 20}}, color = {10, 90, 224}));
      connect(longTransientC.n, p) annotation(Line(visible = true, origin = {125, 10}, points = {{-15, 10}, {-5, 10}, {-5, -10}, {25, -10}}, color = {10, 90, 224}));
      connect(shortTransientR.n, shortTransientC.n) annotation(Line(visible = true, origin = {55, 0}, points = {{-5, -20}, {5, -20}, {5, 20}, {-5, 20}}, color = {10, 90, 224}));
      connect(seriesResistance.n, shortTransientC.p) annotation(Line(visible = true, origin = {20, 10}, points = {{-10, -10}, {0, -10}, {0, 10}, {10, 10}}, color = {10, 90, 224}));
      connect(drawnCurrent.n, seriesResistance.p) annotation(Line(visible = true, origin = {-23.333, -3.333}, points = {{-6.667, -6.667}, {-6.667, 3.333}, {13.333, 3.333}}, color = {10, 90, 224}));
      connect(seriesResistance.n, shortTransientR.p) annotation(Line(visible = true, origin = {22.5, -10}, points = {{-12.5, 10}, {-2.5, 10}, {-2.5, -10}, {7.5, -10}}, color = {10, 90, 224}));
      connect(capacity.p, stateOfCharge.p) annotation(Line(visible = true, origin = {-126.667, 43.333}, points = {{-3.333, -93.333}, {-3.333, 46.667}, {6.667, 46.667}}, color = {10, 90, 224}));
      connect(shortTransientR.n, longTransientR.p) annotation(Line(visible = true, origin = {70, -13.333}, points = {{-20, -6.667}, {-10, -6.667}, {-10, 13.333}, {10, 13.333}, {10, -6.667}, {20, -6.667}}, color = {10, 90, 224}));
      connect(longTransientR.n, p) annotation(Line(visible = true, origin = {125, -10}, points = {{-15, -10}, {-5, -10}, {-5, 10}, {25, 10}}, color = {10, 90, 224}));
      connect(openCircuitVoltage.n, n) annotation(Line(visible = true, origin = {30, -76.667}, points = {{-60, 6.667}, {-60, -3.333}, {120, -3.333}}, color = {10, 90, 224}));
      connect(drainCurrent.n, ground.p) annotation(Line(visible = true, origin = {-96.667, -63.333}, points = {{6.667, 33.333}, {6.667, -16.667}, {6.667, -16.667}}, color = {10, 90, 224}));
      connect(capacity.n, ground.p) annotation(Line(visible = true, origin = {-123.333, -76.667}, points = {{-6.667, 6.667}, {-6.667, -3.333}, {33.333, -3.333}}, color = {10, 90, 224}));
      connect(openCircuitVoltage.p, drawnCurrent.p) annotation(Line(visible = true, origin = {-30, -40}, points = {{0, -10}, {0, 10}}, color = {10, 90, 224}));
      connect(drainCurrent.p, capacity.p) annotation(Line(visible = true, origin = {-110, -15}, points = {{20, 5}, {20, 15}, {-20, 15}, {-20, -35}}, color = {10, 90, 224}));
      annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART BatteryCellDocumentation -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Battery: Battery Cell</h1><a id=\"headerTag_Description\" class=\"target\">&nbsp;</a>
    <h2>Description</h2>
    <p class=\"\">
This is the main part of the battery model. The battery cell can be used in a number of ways, for instance, the cell can be connected in series to form a  <a href=\"modelica://IndustryExamples.Energy.Battery.Components.BatteryPack\">battery pack</a>.
</p><p class=\"\">
The cell has two main circuits with a voltage source and a current source, respectively, connected to variable capacitors and variable resistors. The state of the battery is fed back to the battery cell as input to the variable capacitors and resistors.
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND BatteryCellDocumentation --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Line(visible = true, points = {{-90.0, 0.0}, {-14.0, 0.0}}, color = {0, 0, 255}), Line(visible = true, points = {{14.0, 0.0}, {90.0, 0.0}}, color = {0, 0, 255}), Line(visible = true, points = {{-14.0, 28.0}, {-14.0, -28.0}}, color = {0, 0, 255}, thickness = 0.5), Line(visible = true, points = {{14.0, 28.0}, {14.0, -28.0}}, color = {0, 0, 255}, thickness = 0.5), Text(visible = true, origin = {-6.0, 181.3833}, rotation = -360, lineColor = {0, 0, 255}, extent = {{-144.0, -83.0}, {156.0, -43.0}}, textString = "%name", fontName = "Arial"), Text(visible = true, lineColor = {0, 0, 255}, extent = {{-120.0, 0.0}, {-20.0, 50.0}}, textString = "+", fontName = "Arial"), Text(visible = true, lineColor = {0, 0, 255}, extent = {{20.0, 0.0}, {120.0, 50.0}}, textString = "-", fontName = "Arial"), Rectangle(visible = true, fillColor = {255, 255, 255}, extent = {{-100.0, -100.0}, {100.0, 100.0}})}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end BatteryCell;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
  end Ex6;

  package Ex7 "Models accompanying exercise 7 of the WSM101 Course"
    extends Modelica.Icons.Package;

    model ComponentfromEquation
      extends Modelica.Mechanics.Translational.Interfaces.PartialCompliantWithRelativeStates;
      parameter Real b(final unit = "kg", final min = 0) = 1e-05 "Inertance";
    equation

      annotation(preferredView = "text", Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end ComponentfromEquation;

    model ModelToUseComponent
      extends Modelica.Icons.Example;
      Modelica.Blocks.Sources.Sine sine1(freqHz = 1 / 4) annotation(Placement(visible = true, transformation(origin = {-80.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
      Modelica.Mechanics.Translational.Components.Mass dampedMass(m = 10, L = 0.3) annotation(Placement(visible = true, transformation(origin = {100.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
      Modelica.Mechanics.Translational.Sources.Position position1 annotation(Placement(visible = true, transformation(origin = {-20.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
      Modelica.Mechanics.Translational.Components.Spring spring1(c = 1) annotation(Placement(visible = true, transformation(origin = {20.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.Spring spring2(c = 1) annotation(Placement(visible = true, transformation(origin = {60.0, 40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.Damper damper1(d = 1) annotation(Placement(visible = true, transformation(origin = {60.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Translational.Sources.Position position2 annotation(Placement(visible = true, transformation(origin = {-20.0, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
      Modelica.Mechanics.Translational.Components.Mass undampedMass(L = 0.3, m = 10) annotation(Placement(visible = true, transformation(origin = {100.0, -40.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -360)));
    equation
      connect(spring2.flange_a, spring1.flange_b) annotation(Line(visible = true, origin = {40.0, 40.0}, points = {{10.0, 0.0}, {-10.0, 0.0}}, color = {0, 127, 0}));
      connect(dampedMass.flange_a, spring2.flange_b) annotation(Line(visible = true, origin = {82.75, 35.0}, points = {{7.25, -15.0}, {-2.75, -15.0}, {-2.75, 5.0}, {-12.75, 5.0}}, color = {0, 127, 0}));
      connect(spring1.flange_b, damper1.flange_a) annotation(Line(visible = true, origin = {36.5, 20.0}, points = {{-6.5, 20.0}, {3.5, 20.0}, {3.5, -20.0}, {13.5, -20.0}}, color = {0, 127, 0}));
      connect(spring1.flange_a, position1.flange) annotation(Line(visible = true, origin = {3.4937, 30.0}, points = {{6.5063, 10.0}, {-3.4937, 10.0}, {-3.4937, -10.0}, {-13.4937, -10.0}}, color = {0, 127, 0}));
      connect(damper1.flange_b, dampedMass.flange_a) annotation(Line(visible = true, origin = {76.6125, 10.0}, points = {{-6.6125, -10.0}, {3.3875, -10.0}, {3.3875, 10.0}, {13.3875, 10.0}}, color = {0, 127, 0}));
      connect(sine1.y, position1.s_ref) annotation(Line(visible = true, origin = {-42.75, 10.0}, points = {{-26.25, -10.0}, {7.75, -10.0}, {7.75, 10.0}, {10.75, 10.0}}, color = {0, 0, 127}));
      connect(sine1.y, position2.s_ref) annotation(Line(visible = true, origin = {-42.75, -20.0}, points = {{-26.25, 20.0}, {7.75, 20.0}, {7.75, -20.0}, {10.75, -20.0}}, color = {0, 0, 127}));
      connect(position2.flange, undampedMass.flange_a) annotation(Line(visible = true, origin = {40.0, -40.0}, points = {{-50.0, 0.0}, {50.0, 0.0}}, color = {0, 127, 0}));
      annotation(Documentation(info = "<ul>
   <li>Add an&nbsp;﻿inerter from&nbsp;WSMIntro.Components.Inerter in parallel to spring1.</li>
   <li>Simulate the model for 100s.</li>
   </ul>
   <p><img src=\"documentationFiles/inerterPlot.png\" alt=\"\" /></p>", revisions = ""), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), experiment(StartTime = 0.0, StopTime = 100.0));
    end ModelToUseComponent;

    model Inerter
      extends Modelica.Mechanics.Translational.Interfaces.PartialCompliantWithRelativeStates;
      parameter Real b(final unit = "kg", final min = 0.0001) = 1 "Inertance";
    equation
      f = b * der(v_rel) "Inerter equation";
      annotation(Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, extent = {{-20.0, -40.0}, {20.0, 40.0}}), Line(visible = true, origin = {-55.0, 0.0}, points = {{-35.0, 0.0}, {35.0, 0.0}}), Line(visible = true, origin = {55.0, 0.0}, points = {{-35.0, 0.0}, {35.0, 0.0}}), Text(visible = true, origin = {0.0, 70.0}, fillPattern = FillPattern.Solid, extent = {{-53.8396, -14.176}, {53.8396, 14.176}}, textString = "%name", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end Inerter;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
  end Ex7;

  package Ex11 "Package to create the models of Excercise 11 into"
    extends Modelica.Icons.Package;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
  end Ex11;

  package Ex12 "Package to create the models of Excercise 12 into"
    extends Modelica.Icons.Package;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
  end Ex12;

  package Ex9
    extends Modelica.Icons.Package;

    model DCMotor "Dynamic model of a DC motor"
      Modelica.Blocks.Sources.Step step1 annotation(Placement(visible = true, transformation(origin = {-70.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.Resistor resistor1 annotation(Placement(visible = true, transformation(origin = {-15.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.Inductor inductor1 annotation(Placement(visible = true, transformation(origin = {15.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.EMF EMF1 annotation(Placement(visible = true, transformation(origin = {40.0, -0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.Ground ground1 annotation(Placement(visible = true, transformation(origin = {-15.0, -35.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Sources.SignalVoltage signalVoltage1 annotation(Placement(visible = true, transformation(origin = {-40.0, -0.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 1350)));
      Modelica.Mechanics.Rotational.Components.Inertia inertia1 annotation(Placement(visible = true, transformation(origin = {70.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    equation
      connect(resistor1.n, inductor1.p) annotation(Line(visible = true, origin = {0, 20}, points = {{-5, 0}, {5, 0}}, color = {10, 90, 224}));
      connect(inductor1.n, EMF1.p) annotation(Line(visible = true, origin = {35, 16.667}, points = {{-10, 3.333}, {5, 3.333}, {5, -6.667}}, color = {10, 90, 224}));
      connect(step1.y, signalVoltage1.v) annotation(Line(visible = true, origin = {-53, 0}, points = {{-6, 0}, {6, -0}}, color = {1, 37, 163}));
      connect(signalVoltage1.p, resistor1.p) annotation(Line(visible = true, origin = {-35, 16.667}, points = {{-5, -6.667}, {-5, 3.333}, {10, 3.333}}, color = {10, 90, 224}));
      connect(EMF1.n, signalVoltage1.n) annotation(Line(visible = true, origin = {0, -18.5}, points = {{40, 8.5}, {40, -1.5}, {-40, -1.5}, {-40, 8.5}}, color = {10, 90, 224}));
      connect(ground1.p, signalVoltage1.n) annotation(Line(visible = true, origin = {-30, -19.375}, points = {{15, -5.625}, {15, -0.625}, {-10, -0.625}, {-10, 9.375}}, color = {10, 90, 224}));
      connect(EMF1.flange, inertia1.flange_a) annotation(Line(visible = true, origin = {55, 0}, points = {{-5, 0}, {5, 0}}, color = {64, 64, 64}));
      annotation(__Wolfram(PlotSet(plots = {Plot(name = "StepResponse", preferred = true, subPlots = {SubPlot(curves = {Curve(x = time, y = signalVoltage1.v), Curve(x = time, y = inertia1.w)})})})), experiment(StartTime = 0.0, StopTime = 25), Documentation(info = "<html><p>A simple dynamic model of a controlled DC motor consisting of a variable voltage source, a resistor, an inductor, and an electro-motoric force element representing the coupling between electric energy and mechanical energy provided by the magnetic field in the DC motor. The motor axis is represented by a rotating inertia.</p>
          <p>Comparison of step response for the rotational speed of the inertia using the default parameters (<em>DCMotor 2</em>) and with resistance set to <em>10 Ohm</em>, inductance <em>0.1 H</em>, and moment of inertia to&nbsp;<em>0.3 kg m<sup>2&nbsp;</sup></em> (<em>DCMotor 1</em>):</p>
          <p><img src=\"modelica://IntroductoryExamples/Resources/MultiDomain/image012.png\" border=\"0\" alt=\"\" /></p>
      <p>For a step by step tutorial see <a href=\"wsm:///ref/GettingStarted/MultidomainAServoMechanism.html\">Multidomain—A Servo Mechanism</a>.</p></html>", revisions = ""), Diagram(coordinateSystem(extent = {{-100.0, -60.0}, {100.0, 60.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {112, 31, 0}, fillColor = {255, 85, 0}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 0, extent = {{-50, -75}, {75, 75}}), Polygon(visible = true, lineColor = {50, 16, 0}, fillColor = {231, 58, 0}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 0, points = {{-50, 75}, {-75, 50}, {-75, -50}, {-50, -75}}), Rectangle(visible = true, lineColor = {64, 64, 64}, fillColor = {191, 191, 191}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 0, extent = {{75, -25}, {100, 25}}), Polygon(visible = true, lineColor = {51, 51, 51}, fillColor = {25, 25, 25}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, lineThickness = 0, points = {{-100, -100}, {-100, -87.23}, {-50, -87.23}, {0, 25}, {25, 25}, {75, -86.93000000000001}, {100, -86.93000000000001}, {100, -100}}), Ellipse(visible = true, fillColor = {192, 192, 192}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, lineThickness = 0, extent = {{0, -12.5}, {25, 12.5}})}));
    end DCMotor;

    model DCMotormuell
      Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(Placement(visible = true, transformation(origin = {100.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {100.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput realInput annotation(Placement(visible = true, transformation(origin = {-80.0, 0.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0), iconTransformation(origin = {-120.0, -0.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.Resistor resistor annotation(Placement(visible = true, transformation(origin = {-20.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.Inertia inertia1(J = 0.1) annotation(Placement(visible = true, transformation(origin = {80.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Sources.SignalVoltage signalVoltage1 annotation(Placement(visible = true, transformation(origin = {-40.0, 0.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 1350)));
      Modelica.Electrical.Analog.Basic.Ground ground1 annotation(Placement(visible = true, transformation(origin = {-0.0, -50.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.EMF EMF1(k = EMFk) annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.Inductor inductor1(L = l1) annotation(Placement(visible = true, transformation(origin = {20.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -1440)));
      parameter Modelica.SIunits.Inductance l1 = 1;
      parameter Real EMFk = 1.6;
    equation
      connect(inertia1.flange_b, flange_b) annotation(Line(visible = true, origin = {93.33329999999999, 0.0}, points = {{-3.3333, 0.0}, {-3.3333, 0.0}, {6.6667, 0.0}}));
      connect(signalVoltage1.v, realInput) annotation(Line(visible = true, origin = {-63.5, -0.0}, points = {{16.5, -0.0}, {-16.5, 0.0}}, color = {0, 0, 127}));
      connect(ground1.p, signalVoltage1.n) annotation(Line(visible = true, origin = {-30.0, -19.375}, points = {{30.0, -20.625}, {30.0, -0.625}, {-10.0, -0.625}, {-10.0, 9.375}}, color = {0, 0, 255}));
      connect(EMF1.n, signalVoltage1.n) annotation(Line(visible = true, origin = {0.0, -18.5}, points = {{40.0, 8.5}, {40.0, -1.5}, {-40.0, -1.5}, {-40.0, 8.5}}, color = {0, 0, 255}));
      connect(inductor1.n, EMF1.p) annotation(Line(visible = true, origin = {36.6667, 16.6667}, points = {{-6.6667, 3.3333}, {3.3333, 3.3333}, {3.3333, -6.6667}}, color = {0, 0, 255}));
      connect(EMF1.flange, inertia1.flange_a) annotation(Line(visible = true, origin = {60.0, 0.0}, points = {{-10.0, 0.0}, {10.0, 0.0}}));
      connect(resistor.n, inductor1.p) annotation(Line(visible = true, origin = {0.0, 20.0}, points = {{-10.0, 0.0}, {10.0, 0.0}}, color = {0, 0, 255}));
      connect(resistor.p, signalVoltage1.p) annotation(Line(visible = true, origin = {-40.9611, 19.2243}, points = {{10.9611, 0.7756999999999999}, {0.9611, 0.7756999999999999}, {0.9611, -9.224299999999999}}, color = {0, 0, 255}));
      annotation(Documentation(info = "<ul>
  <li>Insert a new parameter by selecting Insert-&gt;Paramater. Call the the parameter r1 and select the unit to be Resistance from the SI unit drop down list.&nbsp;</li>
  <li>Give it a value of 13, Select the resistor and in the field for R enter r1.</li>
  </ul>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, fillColor = {0, 0, 255}, extent = {{-100.0, -100.0}, {100.0, 100.0}}, radius = 25.0), Text(visible = true, fillPattern = FillPattern.Solid, extent = {{-100.0, -100.0}, {100.0, 100.0}}, textString = "%name", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end DCMotormuell;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
  end Ex9;

  package Ex15
    extends Modelica.Icons.Package;

    model MotorControl
      extends WSM101.Ex15.Motor;
      Modelica.Mechanics.Rotational.Sensors.SpeedSensor speedSensor1 annotation(Placement(visible = true, transformation(origin = {120.0, 60.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealOutput y annotation(Placement(visible = true, transformation(origin = {160.0, 60.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {110.0, 50.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    equation
      connect(y, speedSensor1.w) annotation(Line(visible = true, origin = {145.5, 60.0}, points = {{14.5, 0.0}, {-14.5, -0.0}}, color = {0, 0, 127}));
      connect(speedSensor1.flange, flange_b) annotation(Line(visible = true, origin = {103.3333, 40.0}, points = {{6.6667, 20.0}, {-3.3333, 20.0}, {-3.3333, -40.0}}));
      annotation(Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, fillPattern = FillPattern.Solid, extent = {{-100.0, -150.0}, {100.0, -110.0}}, textString = "%name", fontName = "Arial"), Rectangle(visible = true, lineColor = {112, 31, 0}, fillColor = {255, 85, 0}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 0, extent = {{-50.0, -75.0}, {75.0, 75.0}}), Polygon(visible = true, lineColor = {50, 16, 0}, fillColor = {231, 58, 0}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 0, points = {{-50.0, 75.0}, {-100.0, 33.6021}, {-100.0, -37.3251}, {-50.0, -75.0}}), Rectangle(visible = true, lineColor = {64, 64, 64}, fillColor = {191, 191, 191}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 0, extent = {{75.0, -25.0}, {100.0, 25.0}}), Polygon(visible = true, lineColor = {51, 51, 51}, fillColor = {25, 25, 25}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, lineThickness = 0, points = {{-100.0, -100.0}, {-100.0, -87.23}, {-50.0, -87.23}, {0.0, 25.0}, {25.0, 25.0}, {75.0, -86.93000000000001}, {100.0, -86.93000000000001}, {100.0, -100.0}}), Ellipse(visible = true, fillColor = {192, 192, 192}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, lineThickness = 0, extent = {{0.0, -12.5}, {25.0, 12.5}})}));
    end MotorControl;

    model Example1
      extends Modelica.Icons.Example;
      Modelica.Blocks.Sources.Constant const(k = 1) annotation(Placement(visible = true, transformation(origin = {-60.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      WSM101.Ex15.MotorControl controlMotor1 annotation(Placement(visible = true, transformation(origin = {20.0, -0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Continuous.LimPID PID(Td = 0.5, Ti = 0.5, k = 1000, wd = 1, yMax = 30000) annotation(Placement(visible = true, transformation(origin = {-20.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    equation
      connect(const.y, PID.u_s) annotation(Line(visible = true, origin = {-40.5, 0.0}, points = {{-8.5, 0.0}, {8.5, 0.0}}, color = {0, 0, 127}));
      connect(PID.y, controlMotor1.realInput) annotation(Line(visible = true, origin = {-0.5, -0.0}, points = {{-8.5, 0.0}, {8.5, -0.0}}, color = {0, 0, 127}));
      connect(controlMotor1.y, PID.u_m) annotation(Line(visible = true, origin = {16.8, -11.4}, points = {{14.2, 16.4}, {22.2, 16.4}, {22.2, -8.6}, {-36.8, -8.6}, {-36.8, -0.6}}, color = {0, 0, 127}));
      annotation(experiment(StartTime = 0.0, StopTime = 10), Documentation(info = "<ul>
  <li>Add a FixedShape visualizer from the Modelica.Mechanics.MultiBody.Visualizers library.&nbsp;</li>
  <li>Attach it to the frame_a of the cylinder.&nbsp;</li>
  <li>Specify the .obj file you exported as the parameter shapeType.&nbsp;</li>
  <li>Change the variables width, length, and height of the fixedShape to 1.</li>
  </ul>
  <ul>
  </ul>", revisions = ""), Diagram(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, fillPattern = FillPattern.Solid, extent = {{-100.0, -150.0}, {100.0, -110.0}}, textString = "%name", fontName = "Arial")}));
    end Example1;

    model Example2
      extends Modelica.Icons.Example;
      Modelica.Blocks.Sources.Constant const(k = 1) annotation(Placement(visible = true, transformation(origin = {-80.0, -20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      WSM101.Ex15.MotorControl controlMotor1 annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Math.Add add1 annotation(Placement(visible = true, transformation(origin = {-40.0, -0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Continuous.LimPID PID(Td = 0.5, Ti = 0.5, k = 1000, wd = 1, yMax = 30000) annotation(Placement(visible = true, transformation(origin = {-0.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput u annotation(Placement(visible = true, transformation(origin = {-80.0, 20.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0), iconTransformation(origin = {-87.0479, 35.1896}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0)));
    equation
      connect(add1.u1, u) annotation(Line(visible = true, origin = {-61.275, 13.0}, points = {{9.275, -7.0}, {4.725, -7.0}, {4.725, 7.0}, {-18.725, 7.0}}, color = {0, 0, 127}));
      connect(const.y, add1.u2) annotation(Line(visible = true, origin = {-57.75, -13.0}, points = {{-11.25, -7.0}, {2.75, -7.0}, {2.75, 7.0}, {5.75, 7.0}}, color = {0, 0, 127}));
      connect(add1.y, PID.u_s) annotation(Line(visible = true, origin = {-20.5, 0.0}, points = {{-8.5, -0.0}, {8.5, 0.0}}, color = {0, 0, 127}));
      connect(controlMotor1.y, PID.u_m) annotation(Line(visible = true, origin = {36.8, -11.4}, points = {{14.2, 16.4}, {22.2, 16.4}, {22.2, -8.6}, {-36.8, -8.6}, {-36.8, -0.6}}, color = {0, 0, 127}));
      connect(PID.y, controlMotor1.realInput) annotation(Line(visible = true, origin = {19.5, 0.0}, points = {{-8.5, 0.0}, {8.5, 0.0}}, color = {0, 0, 127}));
      annotation(experiment(StartTime = 0.0, StopTime = 10), Documentation(info = "<ul>
  <li>Add a FixedShape visualizer from the Modelica.Mechanics.MultiBody.Visualizers library.&nbsp;</li>
  <li>Attach it to the frame_a of the cylinder.&nbsp;</li>
  <li>Specify the .obj file you exported as the parameter shapeType.&nbsp;</li>
  <li>Change the variables width, length, and height of the fixedShape to 1.</li>
  </ul>
  <ul>
  </ul>", revisions = ""), Diagram(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Text(visible = true, fillPattern = FillPattern.Solid, extent = {{-100.0, -150.0}, {100.0, -110.0}}, textString = "%name", fontName = "Arial")}));
    end Example2;

    model Motor
      Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(Placement(visible = true, transformation(origin = {100.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {100.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Blocks.Interfaces.RealInput realInput annotation(Placement(visible = true, transformation(origin = {-80.0, 0.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0), iconTransformation(origin = {-120.0, -0.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.Resistor resistor(R = r1) annotation(Placement(visible = true, transformation(origin = {-20.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Mechanics.Rotational.Components.Inertia inertia1(J = 0.1) annotation(Placement(visible = true, transformation(origin = {80.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Sources.SignalVoltage signalVoltage1 annotation(Placement(visible = true, transformation(origin = {-40.0, 0.0}, extent = {{-10.0, 10.0}, {10.0, -10.0}}, rotation = 1350)));
      Modelica.Electrical.Analog.Basic.Ground ground1 annotation(Placement(visible = true, transformation(origin = {-0.0, -50.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.EMF EMF1(k = EMFk) annotation(Placement(visible = true, transformation(origin = {40.0, 0.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
      Modelica.Electrical.Analog.Basic.Inductor inductor1(L = l1) annotation(Placement(visible = true, transformation(origin = {20.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -1440)));
      parameter Modelica.SIunits.Inductance l1 = 1;
      parameter Real EMFk = 1.6;
      parameter Modelica.SIunits.Resistance r1 = 13;
    equation
      connect(inertia1.flange_b, flange_b) annotation(Line(visible = true, origin = {93.33329999999999, 0.0}, points = {{-3.3333, 0.0}, {-3.3333, 0.0}, {6.6667, 0.0}}));
      connect(signalVoltage1.v, realInput) annotation(Line(visible = true, origin = {-63.5, -0.0}, points = {{16.5, -0.0}, {-16.5, 0.0}}, color = {0, 0, 127}));
      connect(ground1.p, signalVoltage1.n) annotation(Line(visible = true, origin = {-30.0, -19.375}, points = {{30.0, -20.625}, {30.0, -0.625}, {-10.0, -0.625}, {-10.0, 9.375}}, color = {0, 0, 255}));
      connect(EMF1.n, signalVoltage1.n) annotation(Line(visible = true, origin = {0.0, -18.5}, points = {{40.0, 8.5}, {40.0, -1.5}, {-40.0, -1.5}, {-40.0, 8.5}}, color = {0, 0, 255}));
      connect(inductor1.n, EMF1.p) annotation(Line(visible = true, origin = {36.6667, 16.6667}, points = {{-6.6667, 3.3333}, {3.3333, 3.3333}, {3.3333, -6.6667}}, color = {0, 0, 255}));
      connect(EMF1.flange, inertia1.flange_a) annotation(Line(visible = true, origin = {60.0, 0.0}, points = {{-10.0, 0.0}, {10.0, 0.0}}));
      connect(resistor.n, inductor1.p) annotation(Line(visible = true, origin = {0.0, 20.0}, points = {{-10.0, 0.0}, {10.0, 0.0}}, color = {0, 0, 255}));
      connect(resistor.p, signalVoltage1.p) annotation(Line(visible = true, origin = {-40.9611, 19.2243}, points = {{10.9611, 0.7756999999999999}, {0.9611, 0.7756999999999999}, {0.9611, -9.224299999999999}}, color = {0, 0, 255}));
      annotation(Documentation(info = "<ul>
  <li>Insert a new parameter by selecting Insert-&gt;Paramater. Call the the parameter r1 and select the unit to be Resistance from the SI unit drop down list.&nbsp;</li>
  <li>Give it a value of 13, Select the resistor and in the field for R enter r1.</li>
  </ul>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, fillColor = {0, 0, 255}, extent = {{-100.0, -100.0}, {100.0, 100.0}}, radius = 25.0), Text(visible = true, fillPattern = FillPattern.Solid, extent = {{-100.0, -100.0}, {100.0, 100.0}}, textString = "%name", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end Motor;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
  end Ex15;

  package Ex16
    extends Modelica.Icons.Package;

    model CamFollowersRound
      Modelica.Mechanics.Rotational.Sources.ConstantSpeed rotator(w_fixed = 5) annotation(Placement(transformation(origin = {-60, 25}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      WSM101.Ex16.CamRound cam annotation(Placement(transformation(origin = {-20, -25}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.Spring follower(c = 2) annotation(Placement(transformation(origin = {20, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.Fixed fixed annotation(Placement(transformation(origin = {60, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(cam.flangeT, follower.flange_a) annotation(Line(visible = true, points = {{-10., -25.}, {-7., -25.}, {-7., -30.}, {7., -30.}, {10., -30.}}, color = {0, 127, 0}, origin = {0, 0}));
      connect(follower.flange_b, fixed.flange) annotation(Line(visible = true, points = {{30., -30.}, {33., -30.}, {33., 15.}, {63., 15.}, {63., 30.}, {60., 30.}}, color = {0, 127, 0}, origin = {0, 0}));
      connect(rotator.flange, cam.flangeR) annotation(Line(visible = true, points = {{-49.98, 25.}, {-46.98, 25.}, {-46.98, -25.}, {-33., -25.}, {-30., -25.}}, color = {64, 64, 64}, origin = {0, 0}));
      annotation(Diagram(coordinateSystem(extent = {{-150, -90}, {150, 90}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Ellipse(visible = true, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, -100}, {100, 100}}), Polygon(visible = true, rotation = 36, lineColor = {63, 63, 63}, fillColor = {160, 160, 164}, fillPattern = FillPattern.HorizontalCylinder, points = {{52.804, 26.569}, {53.594, 27.384}, {54.497, 28.434}, {55.506, 29.769}, {56.611, 31.447}, {57.194, 32.438}, {57.794, 33.546}, {58.406, 34.782}, {59.024, 36.162}, {59.642, 37.702}, {60.251, 39.418}, {60.251, 39.418}, {56.107, 45.122}, {56.107, 45.122}, {49.763, 44.599}, {48.525, 44.371}, {46.88, 43.993}, {45.464, 43.59}, {44.633, 43.316}, {43.209, 42.773}, {41.586, 42.01}, {40.576, 41.277}, {39.655, 40.665}, {38.325, 40.034}, {36.909, 39.63}, {35.446, 39.464}, {26.579, 45.906}, {26.337, 46.984}, {26.222, 48.452}, {26.351, 49.919}, {26.718, 51.345}, {27.102, 52.532}, {27.262, 53.656}, {27.332, 57.054}, {27.129, 60.472}, {27.038, 61.11}, {26.806, 62.47}, {26.496, 63.949}, {26.091, 65.558}, {25.575, 67.305}, {25.575, 67.305}, {18.87, 69.483}, {18.87, 69.483}, {17.426, 68.374}, {16.153, 67.31}, {15.032, 66.295}, {14.045, 65.331}, {13.177, 64.419}, {12.414, 63.558}, {11.159, 61.988}, {10.202, 60.616}, {9.482, 59.433}, {8.951, 58.43}, {8.565, 57.243}, {8.18, 56.208}, {7.474, 54.915}, {6.566, 53.756}, {5.479, 52.762}, {-5.479, 52.762}, {-6.043, 53.237}, {-6.81, 54.032}, {-7.67, 55.227}, {-8.322, 56.547}, {-8.565, 57.243}, {-8.951, 58.43}, {-9.482, 59.433}, {-10.202, 60.616}, {-11.159, 61.988}, {-11.745, 62.748}, {-12.414, 63.558}, {-13.177, 64.419}, {-14.045, 65.331}, {-15.032, 66.295}, {-16.153, 67.31}, {-17.426, 68.374}, {-18.87, 69.483}, {-18.87, 69.483}, {-25.575, 67.305}, {-25.575, 67.305}, {-26.091, 65.558}, {-26.306, 64.737}, {-26.662, 63.194}, {-26.931, 61.775}, {-27.129, 60.472}, {-27.262, 53.656}, {-27.146, 52.79}, {-27.058, 52.287}, {-26.718, 51.345}, {-26.351, 49.919}, {-26.232, 48.82}, {-26.25, 47.715}, {-26.402, 46.622}, {-26.579, 45.906}, {-35.446, 39.464}, {-36.181, 39.518}, {-37.269, 39.71}, {-38.325, 40.034}, {-39.655, 40.665}, {-40.576, 41.277}, {-41.586, 42.01}, {-42.066, 42.254}, {-43.209, 42.773}, {-43.883, 43.042}, {-45.464, 43.59}, {-47.402, 44.122}, {-48.525, 44.371}, {-49.763, 44.599}, {-56.107, 45.122}, {-56.107, 45.122}, {-60.251, 39.418}, {-60.251, 39.418}, {-59.642, 37.702}, {-59.024, 36.162}, {-58.406, 34.782}, {-57.794, 33.546}, {-57.194, 32.438}, {-56.611, 31.447}, {-56.047, 30.56}, {-55.506, 29.769}, {-54.497, 28.434}, {-53.594, 27.384}, {-52.804, 26.569}, {-51.795, 25.834}, {-50.66, 24.897}, {-49.694, 23.786}, {-49.096, 22.856}, {-48.618, 21.86}, {-51.873, 11.093}, {-52.822, 10.529}, {-53.835, 10.086}, {-54.894, 9.771}, {-55.984, 9.59}, {-57.088, 9.544}, {-58.464, 9.524}, {-59.454, 9.348}, {-60.442, 9.122}, {-61.569, 8.81}, {-62.402, 8.542}, {-63.306, 8.22}, {-64.283, 7.834}, {-65.338, 7.374}, {-66.474, 6.831}, {-67.695, 6.19}, {-69.007, 5.438}, {-70.412, 4.556}, {-71.914, 3.525}, {-71.914, 3.525}, {-71.914, -3.525}, {-71.914, -3.525}, {-70.412, -4.556}, {-69.007, -5.438}, {-67.695, -6.19}, {-66.474, -6.831}, {-65.338, -7.374}, {-64.283, -7.834}, {-63.306, -8.22}, {-62.402, -8.542}, {-61.569, -8.81}, {-60.442, -9.122}, {-59.454, -9.348}, {-58.336, -9.543}, {-56.72, -9.544}, {-54.894, -9.771}, {-53.835, -10.086}, {-52.822, -10.529}, {-51.873, -11.093}, {-48.618, -21.86}, {-49.282, -23.174}, {-49.918, -24.078}, {-50.402, -24.634}, {-51.208, -25.389}, {-52.131, -25.949}, {-53.185, -26.95}, {-54.497, -28.434}, {-55.506, -29.769}, {-56.047, -30.56}, {-56.611, -31.447}, {-57.194, -32.438}, {-57.794, -33.546}, {-58.406, -34.782}, {-59.024, -36.162}, {-59.642, -37.702}, {-60.251, -39.418}, {-60.251, -39.418}, {-56.107, -45.122}, {-56.107, -45.122}, {-49.763, -44.599}, {-48.525, -44.371}, {-46.88, -43.993}, {-45.464, -43.59}, {-43.883, -43.042}, {-42.605, -42.509}, {-41.161, -41.778}, {-39.97, -40.856}, {-38.667, -40.171}, {-37.625, -39.803}, {-36.546, -39.566}, {-35.446, -39.464}, {-26.579, -45.906}, {-26.337, -46.984}, {-26.228, -48.083}, {-26.257, -49.188}, {-26.421, -50.281}, {-26.718, -51.345}, {-27.014, -52.057}, {-27.28, -53.814}, {-27.365, -54.849}, {-27.407, -56.045}, {-27.39, -57.42}, {-27.353, -58.18}, {-27.292, -58.993}, {-27.168, -60.163}, {-26.987, -61.438}, {-26.737, -62.828}, {-26.496, -63.949}, {-26.091, -65.558}, {-25.575, -67.305}, {-25.575, -67.305}, {-18.87, -69.483}, {-18.87, -69.483}, {-17.426, -68.374}, {-16.153, -67.31}, {-15.032, -66.295}, {-14.045, -65.331}, {-13.177, -64.419}, {-12.414, -63.558}, {-11.745, -62.748}, {-11.159, -61.988}, {-10.202, -60.616}, {-9.482, -59.433}, {-8.951, -58.43}, {-8.565, -57.243}, {-8.18, -56.208}, {-7.67, -55.227}, {-7.043, -54.317}, {-6.31, -53.491}, {-5.479, -52.762}, {5.479, -52.762}, {6.31, -53.491}, {7.043, -54.317}, {7.67, -55.227}, {8.18, -56.208}, {8.565, -57.243}, {8.951, -58.43}, {9.482, -59.433}, {10.202, -60.616}, {11.159, -61.988}, {11.745, -62.748}, {12.414, -63.558}, {13.177, -64.419}, {14.045, -65.331}, {15.032, -66.295}, {16.153, -67.31}, {17.426, -68.374}, {18.87, -69.483}, {18.87, -69.483}, {25.575, -67.305}, {25.575, -67.305}, {26.091, -65.558}, {26.662, -63.194}, {26.931, -61.775}, {27.129, -60.472}, {27.262, -53.656}, {27.124, -52.659}, {26.718, -51.345}, {26.351, -49.919}, {26.232, -48.82}, {26.25, -47.715}, {26.402, -46.622}, {26.579, -45.906}, {35.446, -39.464}, {36.546, -39.566}, {37.625, -39.803}, {38.667, -40.171}, {39.655, -40.665}, {40.576, -41.277}, {41.586, -42.01}, {42.066, -42.254}, {43.209, -42.773}, {44.633, -43.316}, {45.464, -43.59}, {46.384, -43.861}, {47.402, -44.122}, {48.525, -44.371}, {49.763, -44.599}, {56.107, -45.122}, {56.107, -45.122}, {60.251, -39.418}, {60.251, -39.418}, {59.642, -37.702}, {59.024, -36.162}, {58.406, -34.782}, {57.794, -33.546}, {57.194, -32.438}, {56.611, -31.447}, {56.047, -30.56}, {55.506, -29.769}, {54.497, -28.434}, {53.594, -27.384}, {52.804, -26.569}, {51.497, -25.618}, {50.66, -24.897}, {49.694, -23.786}, {49.096, -22.856}, {48.618, -21.86}, {51.873, -11.093}, {52.822, -10.529}, {53.835, -10.086}, {54.894, -9.771}, {55.984, -9.59}, {57.088, -9.544}, {58.09, -9.577}, {59.454, -9.348}, {60.442, -9.122}, {61.569, -8.81}, {62.402, -8.542}, {63.306, -8.22}, {64.283, -7.834}, {65.338, -7.374}, {66.474, -6.831}, {67.695, -6.19}, {69.007, -5.438}, {70.412, -4.556}, {71.914, -3.525}, {71.914, -3.525}, {71.914, 3.525}, {71.914, 3.525}, {70.412, 4.556}, {69.007, 5.438}, {67.695, 6.19}, {66.474, 6.831}, {65.338, 7.374}, {64.283, 7.834}, {63.306, 8.22}, {61.569, 8.81}, {60.442, 9.122}, {59.454, 9.348}, {58.336, 9.543}, {57.088, 9.544}, {56.351, 9.559}, {55.255, 9.696}, {54.184, 9.966}, {53.154, 10.367}, {51.873, 11.093}, {48.618, 21.86}, {49.482, 23.484}, {50.402, 24.634}, {51.208, 25.389}, {51.795, 25.834}}), Ellipse(visible = true, lineColor = {128, 128, 128}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-25, -25}, {25, 25}}), Text(visible = true, origin = {0, 20}, extent = {{-150, 80}, {150, 120}}, textString = "%name")}));
    end CamFollowersRound;

    model CamFollowersPointy
      Modelica.Mechanics.Rotational.Sources.ConstantSpeed rotator(w_fixed = 5) annotation(Placement(transformation(origin = {-60, 25}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      WSM101.Ex16.CamPointy cam annotation(Placement(transformation(origin = {-20, -25}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.Spring follower(c = 2) annotation(Placement(transformation(origin = {20, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Mechanics.Translational.Components.Fixed fixed annotation(Placement(transformation(origin = {60, 30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(cam.flangeT, follower.flange_a) annotation(Line(visible = true, points = {{-10., -25.}, {-7., -25.}, {-7., -30.}, {7., -30.}, {10., -30.}}, color = {0, 127, 0}, origin = {0, 0}));
      connect(follower.flange_b, fixed.flange) annotation(Line(visible = true, points = {{30., -30.}, {33., -30.}, {33., 15.}, {63., 15.}, {63., 30.}, {60., 30.}}, color = {0, 127, 0}, origin = {0, 0}));
      connect(rotator.flange, cam.flangeR) annotation(Line(visible = true, points = {{-49.98, 25.}, {-46.98, 25.}, {-46.98, -25.}, {-33., -25.}, {-30., -25.}}, color = {64, 64, 64}, origin = {0, 0}));
      annotation(Diagram(coordinateSystem(extent = {{-150, -90}, {150, 90}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Ellipse(visible = true, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, -100}, {100, 100}}), Polygon(visible = true, rotation = 36, lineColor = {63, 63, 63}, fillColor = {160, 160, 164}, fillPattern = FillPattern.HorizontalCylinder, points = {{52.804, 26.569}, {53.594, 27.384}, {54.497, 28.434}, {55.506, 29.769}, {56.611, 31.447}, {57.194, 32.438}, {57.794, 33.546}, {58.406, 34.782}, {59.024, 36.162}, {59.642, 37.702}, {60.251, 39.418}, {60.251, 39.418}, {56.107, 45.122}, {56.107, 45.122}, {49.763, 44.599}, {48.525, 44.371}, {46.88, 43.993}, {45.464, 43.59}, {44.633, 43.316}, {43.209, 42.773}, {41.586, 42.01}, {40.576, 41.277}, {39.655, 40.665}, {38.325, 40.034}, {36.909, 39.63}, {35.446, 39.464}, {26.579, 45.906}, {26.337, 46.984}, {26.222, 48.452}, {26.351, 49.919}, {26.718, 51.345}, {27.102, 52.532}, {27.262, 53.656}, {27.332, 57.054}, {27.129, 60.472}, {27.038, 61.11}, {26.806, 62.47}, {26.496, 63.949}, {26.091, 65.558}, {25.575, 67.305}, {25.575, 67.305}, {18.87, 69.483}, {18.87, 69.483}, {17.426, 68.374}, {16.153, 67.31}, {15.032, 66.295}, {14.045, 65.331}, {13.177, 64.419}, {12.414, 63.558}, {11.159, 61.988}, {10.202, 60.616}, {9.482, 59.433}, {8.951, 58.43}, {8.565, 57.243}, {8.18, 56.208}, {7.474, 54.915}, {6.566, 53.756}, {5.479, 52.762}, {-5.479, 52.762}, {-6.043, 53.237}, {-6.81, 54.032}, {-7.67, 55.227}, {-8.322, 56.547}, {-8.565, 57.243}, {-8.951, 58.43}, {-9.482, 59.433}, {-10.202, 60.616}, {-11.159, 61.988}, {-11.745, 62.748}, {-12.414, 63.558}, {-13.177, 64.419}, {-14.045, 65.331}, {-15.032, 66.295}, {-16.153, 67.31}, {-17.426, 68.374}, {-18.87, 69.483}, {-18.87, 69.483}, {-25.575, 67.305}, {-25.575, 67.305}, {-26.091, 65.558}, {-26.306, 64.737}, {-26.662, 63.194}, {-26.931, 61.775}, {-27.129, 60.472}, {-27.262, 53.656}, {-27.146, 52.79}, {-27.058, 52.287}, {-26.718, 51.345}, {-26.351, 49.919}, {-26.232, 48.82}, {-26.25, 47.715}, {-26.402, 46.622}, {-26.579, 45.906}, {-35.446, 39.464}, {-36.181, 39.518}, {-37.269, 39.71}, {-38.325, 40.034}, {-39.655, 40.665}, {-40.576, 41.277}, {-41.586, 42.01}, {-42.066, 42.254}, {-43.209, 42.773}, {-43.883, 43.042}, {-45.464, 43.59}, {-47.402, 44.122}, {-48.525, 44.371}, {-49.763, 44.599}, {-56.107, 45.122}, {-56.107, 45.122}, {-60.251, 39.418}, {-60.251, 39.418}, {-59.642, 37.702}, {-59.024, 36.162}, {-58.406, 34.782}, {-57.794, 33.546}, {-57.194, 32.438}, {-56.611, 31.447}, {-56.047, 30.56}, {-55.506, 29.769}, {-54.497, 28.434}, {-53.594, 27.384}, {-52.804, 26.569}, {-51.795, 25.834}, {-50.66, 24.897}, {-49.694, 23.786}, {-49.096, 22.856}, {-48.618, 21.86}, {-51.873, 11.093}, {-52.822, 10.529}, {-53.835, 10.086}, {-54.894, 9.771}, {-55.984, 9.59}, {-57.088, 9.544}, {-58.464, 9.524}, {-59.454, 9.348}, {-60.442, 9.122}, {-61.569, 8.81}, {-62.402, 8.542}, {-63.306, 8.22}, {-64.283, 7.834}, {-65.338, 7.374}, {-66.474, 6.831}, {-67.695, 6.19}, {-69.007, 5.438}, {-70.412, 4.556}, {-71.914, 3.525}, {-71.914, 3.525}, {-71.914, -3.525}, {-71.914, -3.525}, {-70.412, -4.556}, {-69.007, -5.438}, {-67.695, -6.19}, {-66.474, -6.831}, {-65.338, -7.374}, {-64.283, -7.834}, {-63.306, -8.22}, {-62.402, -8.542}, {-61.569, -8.81}, {-60.442, -9.122}, {-59.454, -9.348}, {-58.336, -9.543}, {-56.72, -9.544}, {-54.894, -9.771}, {-53.835, -10.086}, {-52.822, -10.529}, {-51.873, -11.093}, {-48.618, -21.86}, {-49.282, -23.174}, {-49.918, -24.078}, {-50.402, -24.634}, {-51.208, -25.389}, {-52.131, -25.949}, {-53.185, -26.95}, {-54.497, -28.434}, {-55.506, -29.769}, {-56.047, -30.56}, {-56.611, -31.447}, {-57.194, -32.438}, {-57.794, -33.546}, {-58.406, -34.782}, {-59.024, -36.162}, {-59.642, -37.702}, {-60.251, -39.418}, {-60.251, -39.418}, {-56.107, -45.122}, {-56.107, -45.122}, {-49.763, -44.599}, {-48.525, -44.371}, {-46.88, -43.993}, {-45.464, -43.59}, {-43.883, -43.042}, {-42.605, -42.509}, {-41.161, -41.778}, {-39.97, -40.856}, {-38.667, -40.171}, {-37.625, -39.803}, {-36.546, -39.566}, {-35.446, -39.464}, {-26.579, -45.906}, {-26.337, -46.984}, {-26.228, -48.083}, {-26.257, -49.188}, {-26.421, -50.281}, {-26.718, -51.345}, {-27.014, -52.057}, {-27.28, -53.814}, {-27.365, -54.849}, {-27.407, -56.045}, {-27.39, -57.42}, {-27.353, -58.18}, {-27.292, -58.993}, {-27.168, -60.163}, {-26.987, -61.438}, {-26.737, -62.828}, {-26.496, -63.949}, {-26.091, -65.558}, {-25.575, -67.305}, {-25.575, -67.305}, {-18.87, -69.483}, {-18.87, -69.483}, {-17.426, -68.374}, {-16.153, -67.31}, {-15.032, -66.295}, {-14.045, -65.331}, {-13.177, -64.419}, {-12.414, -63.558}, {-11.745, -62.748}, {-11.159, -61.988}, {-10.202, -60.616}, {-9.482, -59.433}, {-8.951, -58.43}, {-8.565, -57.243}, {-8.18, -56.208}, {-7.67, -55.227}, {-7.043, -54.317}, {-6.31, -53.491}, {-5.479, -52.762}, {5.479, -52.762}, {6.31, -53.491}, {7.043, -54.317}, {7.67, -55.227}, {8.18, -56.208}, {8.565, -57.243}, {8.951, -58.43}, {9.482, -59.433}, {10.202, -60.616}, {11.159, -61.988}, {11.745, -62.748}, {12.414, -63.558}, {13.177, -64.419}, {14.045, -65.331}, {15.032, -66.295}, {16.153, -67.31}, {17.426, -68.374}, {18.87, -69.483}, {18.87, -69.483}, {25.575, -67.305}, {25.575, -67.305}, {26.091, -65.558}, {26.662, -63.194}, {26.931, -61.775}, {27.129, -60.472}, {27.262, -53.656}, {27.124, -52.659}, {26.718, -51.345}, {26.351, -49.919}, {26.232, -48.82}, {26.25, -47.715}, {26.402, -46.622}, {26.579, -45.906}, {35.446, -39.464}, {36.546, -39.566}, {37.625, -39.803}, {38.667, -40.171}, {39.655, -40.665}, {40.576, -41.277}, {41.586, -42.01}, {42.066, -42.254}, {43.209, -42.773}, {44.633, -43.316}, {45.464, -43.59}, {46.384, -43.861}, {47.402, -44.122}, {48.525, -44.371}, {49.763, -44.599}, {56.107, -45.122}, {56.107, -45.122}, {60.251, -39.418}, {60.251, -39.418}, {59.642, -37.702}, {59.024, -36.162}, {58.406, -34.782}, {57.794, -33.546}, {57.194, -32.438}, {56.611, -31.447}, {56.047, -30.56}, {55.506, -29.769}, {54.497, -28.434}, {53.594, -27.384}, {52.804, -26.569}, {51.497, -25.618}, {50.66, -24.897}, {49.694, -23.786}, {49.096, -22.856}, {48.618, -21.86}, {51.873, -11.093}, {52.822, -10.529}, {53.835, -10.086}, {54.894, -9.771}, {55.984, -9.59}, {57.088, -9.544}, {58.09, -9.577}, {59.454, -9.348}, {60.442, -9.122}, {61.569, -8.81}, {62.402, -8.542}, {63.306, -8.22}, {64.283, -7.834}, {65.338, -7.374}, {66.474, -6.831}, {67.695, -6.19}, {69.007, -5.438}, {70.412, -4.556}, {71.914, -3.525}, {71.914, -3.525}, {71.914, 3.525}, {71.914, 3.525}, {70.412, 4.556}, {69.007, 5.438}, {67.695, 6.19}, {66.474, 6.831}, {65.338, 7.374}, {64.283, 7.834}, {63.306, 8.22}, {61.569, 8.81}, {60.442, 9.122}, {59.454, 9.348}, {58.336, 9.543}, {57.088, 9.544}, {56.351, 9.559}, {55.255, 9.696}, {54.184, 9.966}, {53.154, 10.367}, {51.873, 11.093}, {48.618, 21.86}, {49.482, 23.484}, {50.402, 24.634}, {51.208, 25.389}, {51.795, 25.834}}), Ellipse(visible = true, lineColor = {128, 128, 128}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-25, -25}, {25, 25}}), Text(visible = true, origin = {0, 20}, extent = {{-150, 80}, {150, 120}}, textString = "%name")}));
    end CamFollowersPointy;

    model CamRound
      extends Modelica.Mechanics.Rotational.Interfaces.PartialElementaryRotationalToTranslational;
      Real a;
      Real j;
      Real phi;
      Real s;
      Real v;
    equation
      phi = flangeR.phi + (-1) * internalSupportR.phi;
      s = flangeT.s + (-1) * internalSupportT.s;
      v = der(s);
      a = der(v);
      j = der(a);
      (-1) * flangeT.f = (-1) * flangeR.tau * s ^ (-1) * v ^ (-1) * der(flangeR.phi);
      s = if mod(phi, 2 * Modelica.Constants.pi) > 3 / 2 * Modelica.Constants.pi or mod(phi, 2 * Modelica.Constants.pi) < 1 / 2 * Modelica.Constants.pi then 1 + 1 / 2 * cos(phi) ^ 4 else 1;
      annotation(preferredView = "text", Diagram(coordinateSystem(extent = {{-150, -90}, {150, 90}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Ellipse(visible = true, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, -100}, {100, 100}}), Polygon(visible = true, rotation = 36, lineColor = {63, 63, 63}, fillColor = {160, 160, 164}, fillPattern = FillPattern.HorizontalCylinder, points = {{52.804, 26.569}, {53.594, 27.384}, {54.497, 28.434}, {55.506, 29.769}, {56.611, 31.447}, {57.194, 32.438}, {57.794, 33.546}, {58.406, 34.782}, {59.024, 36.162}, {59.642, 37.702}, {60.251, 39.418}, {60.251, 39.418}, {56.107, 45.122}, {56.107, 45.122}, {49.763, 44.599}, {48.525, 44.371}, {46.88, 43.993}, {45.464, 43.59}, {44.633, 43.316}, {43.209, 42.773}, {41.586, 42.01}, {40.576, 41.277}, {39.655, 40.665}, {38.325, 40.034}, {36.909, 39.63}, {35.446, 39.464}, {26.579, 45.906}, {26.337, 46.984}, {26.222, 48.452}, {26.351, 49.919}, {26.718, 51.345}, {27.102, 52.532}, {27.262, 53.656}, {27.332, 57.054}, {27.129, 60.472}, {27.038, 61.11}, {26.806, 62.47}, {26.496, 63.949}, {26.091, 65.558}, {25.575, 67.305}, {25.575, 67.305}, {18.87, 69.483}, {18.87, 69.483}, {17.426, 68.374}, {16.153, 67.31}, {15.032, 66.295}, {14.045, 65.331}, {13.177, 64.419}, {12.414, 63.558}, {11.159, 61.988}, {10.202, 60.616}, {9.482, 59.433}, {8.951, 58.43}, {8.565, 57.243}, {8.18, 56.208}, {7.474, 54.915}, {6.566, 53.756}, {5.479, 52.762}, {-5.479, 52.762}, {-6.043, 53.237}, {-6.81, 54.032}, {-7.67, 55.227}, {-8.322, 56.547}, {-8.565, 57.243}, {-8.951, 58.43}, {-9.482, 59.433}, {-10.202, 60.616}, {-11.159, 61.988}, {-11.745, 62.748}, {-12.414, 63.558}, {-13.177, 64.419}, {-14.045, 65.331}, {-15.032, 66.295}, {-16.153, 67.31}, {-17.426, 68.374}, {-18.87, 69.483}, {-18.87, 69.483}, {-25.575, 67.305}, {-25.575, 67.305}, {-26.091, 65.558}, {-26.306, 64.737}, {-26.662, 63.194}, {-26.931, 61.775}, {-27.129, 60.472}, {-27.262, 53.656}, {-27.146, 52.79}, {-27.058, 52.287}, {-26.718, 51.345}, {-26.351, 49.919}, {-26.232, 48.82}, {-26.25, 47.715}, {-26.402, 46.622}, {-26.579, 45.906}, {-35.446, 39.464}, {-36.181, 39.518}, {-37.269, 39.71}, {-38.325, 40.034}, {-39.655, 40.665}, {-40.576, 41.277}, {-41.586, 42.01}, {-42.066, 42.254}, {-43.209, 42.773}, {-43.883, 43.042}, {-45.464, 43.59}, {-47.402, 44.122}, {-48.525, 44.371}, {-49.763, 44.599}, {-56.107, 45.122}, {-56.107, 45.122}, {-60.251, 39.418}, {-60.251, 39.418}, {-59.642, 37.702}, {-59.024, 36.162}, {-58.406, 34.782}, {-57.794, 33.546}, {-57.194, 32.438}, {-56.611, 31.447}, {-56.047, 30.56}, {-55.506, 29.769}, {-54.497, 28.434}, {-53.594, 27.384}, {-52.804, 26.569}, {-51.795, 25.834}, {-50.66, 24.897}, {-49.694, 23.786}, {-49.096, 22.856}, {-48.618, 21.86}, {-51.873, 11.093}, {-52.822, 10.529}, {-53.835, 10.086}, {-54.894, 9.771}, {-55.984, 9.59}, {-57.088, 9.544}, {-58.464, 9.524}, {-59.454, 9.348}, {-60.442, 9.122}, {-61.569, 8.81}, {-62.402, 8.542}, {-63.306, 8.22}, {-64.283, 7.834}, {-65.338, 7.374}, {-66.474, 6.831}, {-67.695, 6.19}, {-69.007, 5.438}, {-70.412, 4.556}, {-71.914, 3.525}, {-71.914, 3.525}, {-71.914, -3.525}, {-71.914, -3.525}, {-70.412, -4.556}, {-69.007, -5.438}, {-67.695, -6.19}, {-66.474, -6.831}, {-65.338, -7.374}, {-64.283, -7.834}, {-63.306, -8.22}, {-62.402, -8.542}, {-61.569, -8.81}, {-60.442, -9.122}, {-59.454, -9.348}, {-58.336, -9.543}, {-56.72, -9.544}, {-54.894, -9.771}, {-53.835, -10.086}, {-52.822, -10.529}, {-51.873, -11.093}, {-48.618, -21.86}, {-49.282, -23.174}, {-49.918, -24.078}, {-50.402, -24.634}, {-51.208, -25.389}, {-52.131, -25.949}, {-53.185, -26.95}, {-54.497, -28.434}, {-55.506, -29.769}, {-56.047, -30.56}, {-56.611, -31.447}, {-57.194, -32.438}, {-57.794, -33.546}, {-58.406, -34.782}, {-59.024, -36.162}, {-59.642, -37.702}, {-60.251, -39.418}, {-60.251, -39.418}, {-56.107, -45.122}, {-56.107, -45.122}, {-49.763, -44.599}, {-48.525, -44.371}, {-46.88, -43.993}, {-45.464, -43.59}, {-43.883, -43.042}, {-42.605, -42.509}, {-41.161, -41.778}, {-39.97, -40.856}, {-38.667, -40.171}, {-37.625, -39.803}, {-36.546, -39.566}, {-35.446, -39.464}, {-26.579, -45.906}, {-26.337, -46.984}, {-26.228, -48.083}, {-26.257, -49.188}, {-26.421, -50.281}, {-26.718, -51.345}, {-27.014, -52.057}, {-27.28, -53.814}, {-27.365, -54.849}, {-27.407, -56.045}, {-27.39, -57.42}, {-27.353, -58.18}, {-27.292, -58.993}, {-27.168, -60.163}, {-26.987, -61.438}, {-26.737, -62.828}, {-26.496, -63.949}, {-26.091, -65.558}, {-25.575, -67.305}, {-25.575, -67.305}, {-18.87, -69.483}, {-18.87, -69.483}, {-17.426, -68.374}, {-16.153, -67.31}, {-15.032, -66.295}, {-14.045, -65.331}, {-13.177, -64.419}, {-12.414, -63.558}, {-11.745, -62.748}, {-11.159, -61.988}, {-10.202, -60.616}, {-9.482, -59.433}, {-8.951, -58.43}, {-8.565, -57.243}, {-8.18, -56.208}, {-7.67, -55.227}, {-7.043, -54.317}, {-6.31, -53.491}, {-5.479, -52.762}, {5.479, -52.762}, {6.31, -53.491}, {7.043, -54.317}, {7.67, -55.227}, {8.18, -56.208}, {8.565, -57.243}, {8.951, -58.43}, {9.482, -59.433}, {10.202, -60.616}, {11.159, -61.988}, {11.745, -62.748}, {12.414, -63.558}, {13.177, -64.419}, {14.045, -65.331}, {15.032, -66.295}, {16.153, -67.31}, {17.426, -68.374}, {18.87, -69.483}, {18.87, -69.483}, {25.575, -67.305}, {25.575, -67.305}, {26.091, -65.558}, {26.662, -63.194}, {26.931, -61.775}, {27.129, -60.472}, {27.262, -53.656}, {27.124, -52.659}, {26.718, -51.345}, {26.351, -49.919}, {26.232, -48.82}, {26.25, -47.715}, {26.402, -46.622}, {26.579, -45.906}, {35.446, -39.464}, {36.546, -39.566}, {37.625, -39.803}, {38.667, -40.171}, {39.655, -40.665}, {40.576, -41.277}, {41.586, -42.01}, {42.066, -42.254}, {43.209, -42.773}, {44.633, -43.316}, {45.464, -43.59}, {46.384, -43.861}, {47.402, -44.122}, {48.525, -44.371}, {49.763, -44.599}, {56.107, -45.122}, {56.107, -45.122}, {60.251, -39.418}, {60.251, -39.418}, {59.642, -37.702}, {59.024, -36.162}, {58.406, -34.782}, {57.794, -33.546}, {57.194, -32.438}, {56.611, -31.447}, {56.047, -30.56}, {55.506, -29.769}, {54.497, -28.434}, {53.594, -27.384}, {52.804, -26.569}, {51.497, -25.618}, {50.66, -24.897}, {49.694, -23.786}, {49.096, -22.856}, {48.618, -21.86}, {51.873, -11.093}, {52.822, -10.529}, {53.835, -10.086}, {54.894, -9.771}, {55.984, -9.59}, {57.088, -9.544}, {58.09, -9.577}, {59.454, -9.348}, {60.442, -9.122}, {61.569, -8.81}, {62.402, -8.542}, {63.306, -8.22}, {64.283, -7.834}, {65.338, -7.374}, {66.474, -6.831}, {67.695, -6.19}, {69.007, -5.438}, {70.412, -4.556}, {71.914, -3.525}, {71.914, -3.525}, {71.914, 3.525}, {71.914, 3.525}, {70.412, 4.556}, {69.007, 5.438}, {67.695, 6.19}, {66.474, 6.831}, {65.338, 7.374}, {64.283, 7.834}, {63.306, 8.22}, {61.569, 8.81}, {60.442, 9.122}, {59.454, 9.348}, {58.336, 9.543}, {57.088, 9.544}, {56.351, 9.559}, {55.255, 9.696}, {54.184, 9.966}, {53.154, 10.367}, {51.873, 11.093}, {48.618, 21.86}, {49.482, 23.484}, {50.402, 24.634}, {51.208, 25.389}, {51.795, 25.834}}), Ellipse(visible = true, lineColor = {128, 128, 128}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-25, -25}, {25, 25}}), Text(visible = true, origin = {0, 20}, extent = {{-150, 80}, {150, 120}}, textString = "%name")}));
    end CamRound;

    model CamPointy
      extends Modelica.Mechanics.Rotational.Interfaces.PartialElementaryRotationalToTranslational;
      Real a;
      Real j;
      Real phi;
      Real s;
      Real v;
    equation
      phi = flangeR.phi + (-1) * internalSupportR.phi;
      s = flangeT.s + (-1) * internalSupportT.s;
      v = der(s);
      a = der(v);
      j = der(a);
      (-1) * flangeT.f = (-1) * flangeR.tau * s ^ (-1) * v ^ (-1) * der(flangeR.phi);
      s = if mod(phi, 2 * Modelica.Constants.pi) > 3 / 2 * Modelica.Constants.pi then 4 * (3 * cos(phi) + (-4) * sin(phi)) ^ (-1) else if mod(phi, 2 * Modelica.Constants.pi) < 1 / 2 * Modelica.Constants.pi then (3 / 4 * cos(phi) + sin(phi)) ^ (-1) else 1;
      annotation(preferredView = "text", Diagram(coordinateSystem(extent = {{-150, -90}, {150, 90}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Ellipse(visible = true, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-100, -100}, {100, 100}}), Polygon(visible = true, rotation = 36, lineColor = {63, 63, 63}, fillColor = {160, 160, 164}, fillPattern = FillPattern.HorizontalCylinder, points = {{52.804, 26.569}, {53.594, 27.384}, {54.497, 28.434}, {55.506, 29.769}, {56.611, 31.447}, {57.194, 32.438}, {57.794, 33.546}, {58.406, 34.782}, {59.024, 36.162}, {59.642, 37.702}, {60.251, 39.418}, {60.251, 39.418}, {56.107, 45.122}, {56.107, 45.122}, {49.763, 44.599}, {48.525, 44.371}, {46.88, 43.993}, {45.464, 43.59}, {44.633, 43.316}, {43.209, 42.773}, {41.586, 42.01}, {40.576, 41.277}, {39.655, 40.665}, {38.325, 40.034}, {36.909, 39.63}, {35.446, 39.464}, {26.579, 45.906}, {26.337, 46.984}, {26.222, 48.452}, {26.351, 49.919}, {26.718, 51.345}, {27.102, 52.532}, {27.262, 53.656}, {27.332, 57.054}, {27.129, 60.472}, {27.038, 61.11}, {26.806, 62.47}, {26.496, 63.949}, {26.091, 65.558}, {25.575, 67.305}, {25.575, 67.305}, {18.87, 69.483}, {18.87, 69.483}, {17.426, 68.374}, {16.153, 67.31}, {15.032, 66.295}, {14.045, 65.331}, {13.177, 64.419}, {12.414, 63.558}, {11.159, 61.988}, {10.202, 60.616}, {9.482, 59.433}, {8.951, 58.43}, {8.565, 57.243}, {8.18, 56.208}, {7.474, 54.915}, {6.566, 53.756}, {5.479, 52.762}, {-5.479, 52.762}, {-6.043, 53.237}, {-6.81, 54.032}, {-7.67, 55.227}, {-8.322, 56.547}, {-8.565, 57.243}, {-8.951, 58.43}, {-9.482, 59.433}, {-10.202, 60.616}, {-11.159, 61.988}, {-11.745, 62.748}, {-12.414, 63.558}, {-13.177, 64.419}, {-14.045, 65.331}, {-15.032, 66.295}, {-16.153, 67.31}, {-17.426, 68.374}, {-18.87, 69.483}, {-18.87, 69.483}, {-25.575, 67.305}, {-25.575, 67.305}, {-26.091, 65.558}, {-26.306, 64.737}, {-26.662, 63.194}, {-26.931, 61.775}, {-27.129, 60.472}, {-27.262, 53.656}, {-27.146, 52.79}, {-27.058, 52.287}, {-26.718, 51.345}, {-26.351, 49.919}, {-26.232, 48.82}, {-26.25, 47.715}, {-26.402, 46.622}, {-26.579, 45.906}, {-35.446, 39.464}, {-36.181, 39.518}, {-37.269, 39.71}, {-38.325, 40.034}, {-39.655, 40.665}, {-40.576, 41.277}, {-41.586, 42.01}, {-42.066, 42.254}, {-43.209, 42.773}, {-43.883, 43.042}, {-45.464, 43.59}, {-47.402, 44.122}, {-48.525, 44.371}, {-49.763, 44.599}, {-56.107, 45.122}, {-56.107, 45.122}, {-60.251, 39.418}, {-60.251, 39.418}, {-59.642, 37.702}, {-59.024, 36.162}, {-58.406, 34.782}, {-57.794, 33.546}, {-57.194, 32.438}, {-56.611, 31.447}, {-56.047, 30.56}, {-55.506, 29.769}, {-54.497, 28.434}, {-53.594, 27.384}, {-52.804, 26.569}, {-51.795, 25.834}, {-50.66, 24.897}, {-49.694, 23.786}, {-49.096, 22.856}, {-48.618, 21.86}, {-51.873, 11.093}, {-52.822, 10.529}, {-53.835, 10.086}, {-54.894, 9.771}, {-55.984, 9.59}, {-57.088, 9.544}, {-58.464, 9.524}, {-59.454, 9.348}, {-60.442, 9.122}, {-61.569, 8.81}, {-62.402, 8.542}, {-63.306, 8.22}, {-64.283, 7.834}, {-65.338, 7.374}, {-66.474, 6.831}, {-67.695, 6.19}, {-69.007, 5.438}, {-70.412, 4.556}, {-71.914, 3.525}, {-71.914, 3.525}, {-71.914, -3.525}, {-71.914, -3.525}, {-70.412, -4.556}, {-69.007, -5.438}, {-67.695, -6.19}, {-66.474, -6.831}, {-65.338, -7.374}, {-64.283, -7.834}, {-63.306, -8.22}, {-62.402, -8.542}, {-61.569, -8.81}, {-60.442, -9.122}, {-59.454, -9.348}, {-58.336, -9.543}, {-56.72, -9.544}, {-54.894, -9.771}, {-53.835, -10.086}, {-52.822, -10.529}, {-51.873, -11.093}, {-48.618, -21.86}, {-49.282, -23.174}, {-49.918, -24.078}, {-50.402, -24.634}, {-51.208, -25.389}, {-52.131, -25.949}, {-53.185, -26.95}, {-54.497, -28.434}, {-55.506, -29.769}, {-56.047, -30.56}, {-56.611, -31.447}, {-57.194, -32.438}, {-57.794, -33.546}, {-58.406, -34.782}, {-59.024, -36.162}, {-59.642, -37.702}, {-60.251, -39.418}, {-60.251, -39.418}, {-56.107, -45.122}, {-56.107, -45.122}, {-49.763, -44.599}, {-48.525, -44.371}, {-46.88, -43.993}, {-45.464, -43.59}, {-43.883, -43.042}, {-42.605, -42.509}, {-41.161, -41.778}, {-39.97, -40.856}, {-38.667, -40.171}, {-37.625, -39.803}, {-36.546, -39.566}, {-35.446, -39.464}, {-26.579, -45.906}, {-26.337, -46.984}, {-26.228, -48.083}, {-26.257, -49.188}, {-26.421, -50.281}, {-26.718, -51.345}, {-27.014, -52.057}, {-27.28, -53.814}, {-27.365, -54.849}, {-27.407, -56.045}, {-27.39, -57.42}, {-27.353, -58.18}, {-27.292, -58.993}, {-27.168, -60.163}, {-26.987, -61.438}, {-26.737, -62.828}, {-26.496, -63.949}, {-26.091, -65.558}, {-25.575, -67.305}, {-25.575, -67.305}, {-18.87, -69.483}, {-18.87, -69.483}, {-17.426, -68.374}, {-16.153, -67.31}, {-15.032, -66.295}, {-14.045, -65.331}, {-13.177, -64.419}, {-12.414, -63.558}, {-11.745, -62.748}, {-11.159, -61.988}, {-10.202, -60.616}, {-9.482, -59.433}, {-8.951, -58.43}, {-8.565, -57.243}, {-8.18, -56.208}, {-7.67, -55.227}, {-7.043, -54.317}, {-6.31, -53.491}, {-5.479, -52.762}, {5.479, -52.762}, {6.31, -53.491}, {7.043, -54.317}, {7.67, -55.227}, {8.18, -56.208}, {8.565, -57.243}, {8.951, -58.43}, {9.482, -59.433}, {10.202, -60.616}, {11.159, -61.988}, {11.745, -62.748}, {12.414, -63.558}, {13.177, -64.419}, {14.045, -65.331}, {15.032, -66.295}, {16.153, -67.31}, {17.426, -68.374}, {18.87, -69.483}, {18.87, -69.483}, {25.575, -67.305}, {25.575, -67.305}, {26.091, -65.558}, {26.662, -63.194}, {26.931, -61.775}, {27.129, -60.472}, {27.262, -53.656}, {27.124, -52.659}, {26.718, -51.345}, {26.351, -49.919}, {26.232, -48.82}, {26.25, -47.715}, {26.402, -46.622}, {26.579, -45.906}, {35.446, -39.464}, {36.546, -39.566}, {37.625, -39.803}, {38.667, -40.171}, {39.655, -40.665}, {40.576, -41.277}, {41.586, -42.01}, {42.066, -42.254}, {43.209, -42.773}, {44.633, -43.316}, {45.464, -43.59}, {46.384, -43.861}, {47.402, -44.122}, {48.525, -44.371}, {49.763, -44.599}, {56.107, -45.122}, {56.107, -45.122}, {60.251, -39.418}, {60.251, -39.418}, {59.642, -37.702}, {59.024, -36.162}, {58.406, -34.782}, {57.794, -33.546}, {57.194, -32.438}, {56.611, -31.447}, {56.047, -30.56}, {55.506, -29.769}, {54.497, -28.434}, {53.594, -27.384}, {52.804, -26.569}, {51.497, -25.618}, {50.66, -24.897}, {49.694, -23.786}, {49.096, -22.856}, {48.618, -21.86}, {51.873, -11.093}, {52.822, -10.529}, {53.835, -10.086}, {54.894, -9.771}, {55.984, -9.59}, {57.088, -9.544}, {58.09, -9.577}, {59.454, -9.348}, {60.442, -9.122}, {61.569, -8.81}, {62.402, -8.542}, {63.306, -8.22}, {64.283, -7.834}, {65.338, -7.374}, {66.474, -6.831}, {67.695, -6.19}, {69.007, -5.438}, {70.412, -4.556}, {71.914, -3.525}, {71.914, -3.525}, {71.914, 3.525}, {71.914, 3.525}, {70.412, 4.556}, {69.007, 5.438}, {67.695, 6.19}, {66.474, 6.831}, {65.338, 7.374}, {64.283, 7.834}, {63.306, 8.22}, {61.569, 8.81}, {60.442, 9.122}, {59.454, 9.348}, {58.336, 9.543}, {57.088, 9.544}, {56.351, 9.559}, {55.255, 9.696}, {54.184, 9.966}, {53.154, 10.367}, {51.873, 11.093}, {48.618, 21.86}, {49.482, 23.484}, {50.402, 24.634}, {51.208, 25.389}, {51.795, 25.834}}), Ellipse(visible = true, lineColor = {128, 128, 128}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, extent = {{-25, -25}, {25, 25}}), Text(visible = true, origin = {0, 20}, extent = {{-150, 80}, {150, 120}}, textString = "%name")}));
    end CamPointy;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
  end Ex16;

  package Ex17
    extends Modelica.Icons.Package;

    model TwoCapacitors
      Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor1(C = 15, T.start = 393.15) annotation(Placement(visible = true, transformation(origin = {-35, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor2(C = 15, T.start = 293.15) annotation(Placement(visible = true, transformation(origin = {47.82, 37.977}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Components.ThermalConductor thermalConductor1(G = 10) annotation(Placement(visible = true, transformation(origin = {7.023, 5}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Celsius.TemperatureSensor temperatureSensor1 annotation(Placement(visible = true, transformation(origin = {-12.82, -26.882}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Celsius.TemperatureSensor temperatureSensor2 annotation(Placement(visible = true, transformation(origin = {30, -27.578}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    equation
      connect(heatCapacitor1.port, thermalConductor1.port_a) annotation(Line(visible = true, origin = {-24.326, 13.333}, points = {{-10.674, 16.667}, {-10.674, -8.333}, {21.349, -8.333}}, color = {191, 0, 0}));
      connect(thermalConductor1.port_b, heatCapacitor2.port) annotation(Line(visible = true, origin = {37.555, 12.659}, points = {{-20.531, -7.659}, {10.266, -7.659}, {10.266, 15.318}}, color = {191, 0, 0}));
      connect(temperatureSensor1.port, heatCapacitor1.port) annotation(Line(visible = true, origin = {-30.94, -7.921}, points = {{8.12, -18.961}, {-4.06, -18.961}, {-4.06, 37.921}}, color = {191, 0, 0}));
      connect(temperatureSensor2.port, heatCapacitor2.port) annotation(Line(visible = true, origin = {45.214, -9.06}, points = {{-5.214, -18.518}, {2.607, -18.518}, {2.607, 37.037}}, color = {191, 0, 0}));
      annotation(Diagram(coordinateSystem(extent = {{-150, -90}, {150, 90}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {0, 114, 195}, fillColor = {255, 255, 255}, extent = {{-100, -100}, {100, 100}}, radius = 25), Text(visible = true, textColor = {64, 64, 64}, extent = {{-150, 110}, {150, 150}}, textString = "%name")}));
    end TwoCapacitors;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
  end Ex17;

  package Ex18
    extends Modelica.Icons.Package;

    model ThermalModel
      extends Modelica.Icons.Example;
      Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor(C = 4000, T.start = 293.15) annotation(Placement(visible = true, transformation(origin = {-60, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Components.HeatCapacitor heatCapacitor1(C = 4000, T.start = 393.15) annotation(Placement(visible = true, transformation(origin = {60, 40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Components.BodyRadiation bodyRadiation(Gr = 0.85) annotation(Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
      TemperatureSensorDynamic temperatureSensorDynamic1 annotation(Placement(visible = true, transformation(origin = {22.627, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    equation
      connect(bodyRadiation.port_a, heatCapacitor.port) annotation(Line(visible = true, origin = {-43.333, 10}, points = {{33.333, -10}, {-16.667, -10}, {-16.667, 20}}, color = {191, 0, 0}));
      connect(bodyRadiation.port_b, heatCapacitor1.port) annotation(Line(visible = true, origin = {43.333, 10}, points = {{-33.333, -10}, {16.667, -10}, {16.667, 20}}, color = {191, 0, 0}));
      connect(bodyRadiation.port_a, temperatureSensorDynamic1.port) annotation(Line(visible = true, origin = {-6.843, -20}, points = {{-3.157, 20}, {-8.157, 20}, {-8.157, -20}, {19.47, -20}}, color = {191, 0, 0}));
      annotation(Documentation(info = "<!-- p, li { white-space: pre-wrap; } -->
 <p><!--StartFragment-->A simple thermal model with dynamic parts added by course participants.</p>", revisions = ""), experiment(StopTime = 1000.0), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-105, -74}, {105, 74}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
    end ThermalModel;

    model TemperatureSensorDynamic "Absolute temperature sensor in degCelsius"
      Modelica.Blocks.Interfaces.RealOutput T(unit = "degC") "Absolute temperature in degree Celsius as output signal" annotation(Placement(transformation(extent = {{90, -10}, {110, 10}}, rotation = 0)));
      Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a port annotation(Placement(transformation(extent = {{-110, -10}, {-90, 10}}, rotation = 0)));
      Real var;
    equation
      T = Modelica.SIunits.Conversions.to_degC(port.T);
      port.Q_flow = 0;
      var = T;
      annotation(preferedView = "icon", Diagram(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, initialScale = 0.1, grid = {10, 10}), graphics = {Ellipse(visible = true, fillColor = {191, 0, 0}, fillPattern = FillPattern.Solid, lineThickness = 0.5, extent = {{-20, -98}, {20, -60}}), Line(visible = true, points = {{12, 0}, {90, 0}}, color = {0, 0, 255}), Line(visible = true, points = {{-94, 0}, {-12, 0}}, color = {191, 0, 0}), Polygon(visible = true, lineThickness = 0.5, points = {{-12, 40}, {-12, 80}, {-10, 86}, {-6, 88}, {0, 90}, {6, 88}, {10, 86}, {12, 80}, {12, 40}, {-12, 40}}), Line(visible = true, points = {{-12, 40}, {-12, -64}}, thickness = 0.5), Line(visible = true, points = {{12, 40}, {12, -64}}, thickness = 0.5), Line(visible = true, points = {{-40, -20}, {-12, -20}}), Line(visible = true, points = {{-40, 20}, {-12, 20}}), Line(visible = true, points = {{-40, 60}, {-12, 60}}), Text(visible = true, extent = {{60, -74}, {102, -22}}, textString = "degC")}), Icon(coordinateSystem(preserveAspectRatio = true, extent = {{-100, -100}, {100, 100}}, initialScale = 0.1, grid = {10, 10}), graphics = {Ellipse(visible = true, fillColor = {191, 0, 0}, fillPattern = FillPattern.Solid, lineThickness = 0.5, extent = {{-20, -98}, {20, -60}}), Rectangle(visible = true, origin = {0, -59.481}, lineColor = {191, 0, 0}, fillColor = {191, 0, 0}, fillPattern = FillPattern.Solid, extent = DynamicSelect({{-12, -2}, {12, 1.481}}, {{-12, -2}, {12, 2}})), Line(visible = true, points = {{12, 0}, {90, 0}}, color = {0, 0, 255}), Line(visible = true, points = {{-90, 0}, {-12, 0}}, color = {191, 0, 0}), Polygon(visible = true, lineThickness = 0.5, points = {{-12, 40}, {-12, 80}, {-10, 86}, {-6, 88}, {0, 90}, {6, 88}, {10, 86}, {12, 80}, {12, 40}, {-12, 40}}), Line(visible = true, points = {{-12, 40}, {-12, -64}}, thickness = 0.5), Line(visible = true, points = {{12, 40}, {12, -64}}, thickness = 0.5), Line(visible = true, points = {{-40, -20}, {-12, -20}}), Line(visible = true, points = {{-40, 20}, {-12, 20}}), Line(visible = true, points = {{-40, 60}, {-12, 60}}), Text(visible = true, extent = {{30, -92}, {150, -22}}, textString = "degC"), Text(visible = true, textColor = {0, 0, 255}, extent = {{-150, 95}, {150, 135}}, textString = "%name"), Rectangle(visible = true, origin = {60, -65.21}, fillColor = {255, 255, 255}, extent = {{-0, -0.267}, {0, 0.267}})}), Documentation(info = "<HTML>
 <p>
 This is an ideal absolute temperature sensor which returns
 the temperature of the connected port in Celsius as an output
 signal.  The sensor itself has no thermal interaction with
 whatever it is connected to.  Furthermore, no
 thermocouple-like lags are associated with this
 sensor model.
 </p>
 </html>"));
    end TemperatureSensorDynamic;
    annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
  end Ex18;
  annotation(Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {0.248, 0.044}, lineColor = {56, 56, 56}, fillColor = {128, 202, 255}, fillPattern = FillPattern.Solid, points = {{99.752, 100}, {99.752, 59.956}, {99.752, -50}, {100, -100}, {49.752, -100}, {-19.752, -100.044}, {-100.248, -100}, {-100.248, -50}, {-90.248, 29.956}, {-90.248, 79.956}, {-40.248, 79.956}, {-20.138, 79.813}, {-0.248, 79.956}, {19.752, 99.956}, {39.752, 99.956}, {59.752, 99.956}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {0, -13.079}, lineColor = {192, 192, 192}, fillColor = {255, 255, 255}, pattern = LinePattern.None, fillPattern = FillPattern.HorizontalCylinder, points = {{100, -86.921}, {50, -86.921}, {-50, -86.921}, {-100, -86.921}, {-100, -36.921}, {-100, 53.079}, {-100, 103.079}, {-50, 103.079}, {0, 103.079}, {20, 83.079}, {50, 83.079}, {100, 83.079}, {100, 33.079}, {100, -36.921}}, smooth = Smooth.Bezier), Rectangle(visible = true, origin = {0, -5}, lineColor = {198, 198, 198}, fillColor = {238, 238, 238}, pattern = LinePattern.None, fillPattern = FillPattern.Solid, extent = {{-100, -25}, {100, 25}}), Polygon(visible = true, origin = {-0, -10.704}, lineColor = {113, 113, 113}, fillColor = {255, 255, 255}, points = {{100, -89.296}, {50, -89.296}, {-50, -89.296}, {-100, -89.296}, {-100, -39.296}, {-100, 50.704}, {-100, 100.704}, {-50, 100.704}, {0, 100.704}, {20, 80.704}, {50, 80.704}, {100, 80.704}, {100, 30.704}, {100, -39.296}}, smooth = Smooth.Bezier)}));
end WSM101;
